This project began as an entry to a `Python Game Jam <https://itch.io/jam/python-game-jam-8>`_.

In the spirit of that Jam, the theme for the work is `The Unknown`. I began to have ideas for a story,
and quickly realised I would need a `Dialogue Tree <https://en.wikipedia.org/wiki/Dialogue_tree>`_.

So I parked the story ideas and went back to work on `Balladeer <https://tundish.github.io/balladeer/>`_ to
add the functionality I needed. The good news is that Balladeer now supports
`Conversation Trees <https://balladeer.readthedocs.io/en/latest/conversation.html>`_!

The downside was that I ran out of time to submit my Jam entry. I still have the notes I made, so this
repository will remain a work-in-progress for a while.
